package callcenter.controllers;

import callcenter.Service.ReportService;
import callcenter.models.CallLog;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;
import java.io.IOException;
import java.util.List;

@RestController
@RequestMapping("/reports")
public class ReportController {

    private final ReportService reportService;

    @Autowired
    public ReportController(ReportService reportService){
        this.reportService = reportService;
    }

    @PostMapping("/upload")
    public ResponseEntity<String> uploadReport(@RequestParam("file") MultipartFile file) {
        try {
            File reportFile = new File(file.getOriginalFilename());
            file.transferTo(reportFile);

            reportService.processReport(reportFile);

            reportFile.delete();

            return ResponseEntity.ok("{\"message\": \"Отчет успешно загружен и обработан\"}");
        } catch (IOException e){
            e.printStackTrace();
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR)
                    .body("{\"error\": \"Произошла ошибка при загрузке и обработке отчета.\"}");
        }
    }

    @GetMapping("/summary")
    public ResponseEntity<?> getReportSummary() {
        try {
            // Выполнение запроса к базе данных для получения данных отчета
            List<CallLog> reportData = reportService.getReportData();

            ObjectMapper objectMapper = new ObjectMapper();
            String jsonData = objectMapper.writeValueAsString(reportData);

            // Возвращаем успешный ответ с данными отчета в виде json- файла
            return ResponseEntity.ok()
                    .header("Content-Type", "application/json")
                    .body(jsonData);

        } catch (Exception e) {
            e.printStackTrace();
            // Возвращаем ответ с ошибкой
            return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR)
                    .body("{\"error\": \"Произошла ошибка при получении данных отчета.\"}");
        }
    }


}
